Composes — bodhi 4.0.0 documentation

# Composes

`cornice_sphinx` does not yet have the ability to render documentation for the `/composes/` API, so we will include docblock documentation for that service here instead.

class `bodhi.server.services.composes.` `Composes`(request, context=None)

  Defines resources for interacting with Compose objects.

  Operations acting on the collection are served at `/composes/` and operations acting on a single compose are served at `/composes/<release_name>/<request>`.

  `collection_get`()

    List composes.

    This method responds to the `/composes/` endpoint.

    Returns: | A dictionary mapping the key ‘composes’ to an iterable of all Compose objects.
    Return type: | dict

  `get`()

    Retrieve and render a single compose.

    This API responses to the `/composes/<release_name>/<request>` endpoint.

    Returns: | A dictionary mapping the key ‘compose’ to a single Compose object.
    Return type: | dict